/* $Workfile: OsaThrd.h $   $Revision: 12 $    $Modtime: 8/06/04 2:51p $  */
#ifndef OSA_TRHD_H
#define OSA_TRHD_H
/*******************************************************************************

  @doc PublicHwApi OsaThrd

  Copyright (C) 1999 - 2003 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OsaThrd | This file contains prototypes for platform the
  generic implementation of some thread and mutex functions.

  @contents2
  OsaThrd.h |

  @index func | OsaThrd

  @contents2
  Generic Thread and Mutex Functions - OsaThreadXXX()/OsaMutexXXX() | A platform 
  generic implementation of some thread and mutex functions.
  
  @head3 OsaThreadXXX()/OsaMutexXXX() Function Reference |

  @index func | OsaThrd

*******************************************************************************/

#if defined(__cplusplus)
extern "C" {
#endif

#if defined(OSA_DRIVER)
#if OSA_NDIS
#include <ndis.h>
#else
#error "DRVLIB platform not supported"
#endif
#include "DrvLib/OsaDrvLibThrd.h"

#elif defined(__linux__)
#include <pthread.h>
#include "Linux/OsaLinuxThrd.h"

#elif defined(_WIN32_WCE)
#include <windows.h>
#include "WindowsCe/OsaWindowsCeThrd.h"

#elif defined(WIN32)
#include <windows.h>
#include "W32/OsaWin32Thrd.h"

#else

#error "Platform not supported"

#endif

typedef void * (*OsaThreadFnP)(void *pContext);


/******************************************************************************

  @func
    Platform generic Osa implementation of the Win32 Sleep() function.

  @comm
    Osa functions are used by the demo programs.

  @ex |
    // sleep for 500 ms  
    OsaThreadSleep(500);

  @xref
    <f OsaConsoleInit>

******************************************************************************/
OTX_EXPORT void OTX_API OsaThreadSleep(
  unsigned long   nMilliSecs      // @parm Sleep time in milliseconds 
);


/******************************************************************************

  @func
    Platform generic Osa implementation of the Win32 CreateThread() function.

  @comm
    Osa functions are used by the demo programs.

  @ex |

    void  *DemoIdleFunction(
      void *lpParameter   // thread data
    )
    {
      OTX_RESULT result;

      while (1) {
        OtxDrvWaitForSingleEvent(
           g_hNotificationEvent, 
           OTX_TIME_INFINITY);

        do {
          OtxEventDataS eventData;
          result = OtxDrvGetEventData(
                      g_hEventQueue, 
                      &eventData); 

          if (OTX_RESULT_CODE(result) == OTX_S_OK) {
            // We have a driver event
            // Printf the event data.
            // In a real application branch based on the data
            DemoPrintEvent(&eventData);
          }
        } while (OTX_RESULT_CODE(result) == OTX_S_OK);
      }

      return 0;
    }

    // start a thread 
    OsaThreadStart(DemoIdleFunction);

  @xref
    <f OsaConsoleInit>

******************************************************************************/
OTX_EXPORT void OTX_API OsaThreadStart(
  OsaThreadFnP    pfnThreadFunc   // @parm Thread function to be started
);


/******************************************************************************

  @func
    Platform generic Osa implementation of the Win32 CreateThread() function,
    the difference from <f OsaThreadStart> is that this function can pass a 
    parameter.

  @comm
    Osa functions are used by the demo programs.

    see example on <f OsaThreadStart>

  @xref
    <f OsaConsoleInit>

******************************************************************************/
OTX_EXPORT void OTX_API OsaThreadStartEx(
  OsaThreadFnP    pfnThreadFunc,  // @parm Thread function to be started
  void            *lpParameter    // @parm Parameter to be passed to the thread
);


/******************************************************************************

  @func
    Initalize a Mutex that can be used to create a critical section.

  @comm
    Osa functions are used by the demo programs.

  @ex |
    static OsaMutexS g_demoLogfCritSec;

	  OsaConsoleInit();
    
    OsaMutexInit(&g_demoLogfCritSec);

    ......
    
    // delete a Mutex 
    OsaMutexDestroy(&g_demoLogfCritSec);
    
    OsaConsoleExit();

  @xref
    <f OsaConsoleInit>
    <f OsaMutexLock>
    <f OsaMutexUnlock>

******************************************************************************/
OTX_EXPORT void OTX_API OsaMutexInit(
  OsaMutexS       *pMutex         // @parm Pointer to the mutex created by this function call
);


/******************************************************************************

  @func
    Starts a critical section.

  @comm
    Osa functions are used by the demo programs.

  @ex |

    OsaMutexS g_demoLogfCritSec;

    static void DemoLogf(char *formatStr, ...)
    {
      va_list argList;

      OsaMutexLock(&g_demoLogfCritSec);

      va_start(argList, formatStr);

      OsaConsolePrintF(formatStr, argList);
      if (g_pDemoLogFile) vfprintf(g_pDemoLogFile,   formatStr, argList);

      va_end(argList);

      OsaMutexUnlock(&g_demoLogfCritSec);

    }

  @xref
    <f OsaConsoleInit>
    <f OsaMutexInit>
    <f OsaMutexUnlock>

******************************************************************************/
OTX_EXPORT void OTX_API OsaMutexLock(
  OsaMutexS       *pMutex         // @parm Pointer to the mutex created by a call to <f OsaMutexInit>
);


/******************************************************************************

  @func
    Ends a critical section

  @comm
    Osa functions are used by the demo programs.

    see example on <f OsaMutexLock> 

  @xref
    <f OsaConsoleInit>
    <f OsaMutexLock>

******************************************************************************/
OTX_EXPORT void OTX_API OsaMutexUnlock(
  OsaMutexS       *pMutex         // @parm Pointer to the mutex created by a call to <f OsaMutexInit>
);


/******************************************************************************

  @func
    Deletes a Mutex created by <f OsaMutexInit>

  @comm
    Osa functions are used by the demo programs.

  see example on <f OsaMutexInit> 

  @xref
    <f OsaConsoleInit>
    <f OsaMutexInit>

******************************************************************************/
OTX_EXPORT void OTX_API OsaMutexDestroy(
  OsaMutexS       *pMutex         // @parm Pointer to the mutex created by a call to <f OsaMutexInit>
);



#ifdef __cplusplus
  } // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1999 - 2003

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/

#endif // OSA_TRHD_H
