/* $Workfile: OtxErr.h $   $Revision: 45 $    $Modtime: 10/29/04 2:12p $  */
#ifndef OTX_ERR_H
#define OTX_ERR_H
/*******************************************************************************

  Copyright (C) 1998 - 2004 Odin TeleSystems Inc., All Rights Reserved

  @doc PublicHwApi OtxErr

  OTX Generic Hardware Driver API

  @module

    OtxErr |

    Odin Telecom FrameworX (OTX) standard result structure.

    OTX error definitions and values

    The return value of OTX APIs and methods is an OTX_RESULT.
    This is not a handle to anything, but is merely a 32-bit value
    with several fields encoded in the value.  The parts of an
    OTX_RESULT are shown below.

    The structure of OTX_RESULT is based on the Win32 HRESULT
    layout, but the meanings of values used in the bit fields
    are completely different.


     @ex OTX_RESULTs are 32 bit values layed out as follows: |


     |3 3 2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
     |1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
     |-+---------------+-----------------------------+---------------+
     |S|  source id    |        line number          |      Code     |
     |-+---------------+-----------------------------+---------------+

     @ex where |

     S - Severity - indicates success/fail

         0 - Success
         1 - Fail

     source id - source module where error occurred

     line number - line number where error occurred

     X - extended error flag

     Code - is the OTX facility's status code


  @contents2
  OtxErr.h |

  @index enum struct type | OtxErr

  @contents2
  OTX Driver Level Result Codes |

  @index enum struct type | OtxErr

*******************************************************************************/

// Severity values
#define OTX_SEVERITY_SUCCESS    0
#define OTX_SEVERITY_ERROR      1


// @type OTX_SUCCESS | Generic test for success on any status value (non-negative numbers indicate success).
#define OTX_SUCCESS(status) ((OTX_RESULT)(status) >= 0)

// @type OTX_FAILURE | Generic test for success on any status value (negative numbers indicate failure).
#define OTX_FAILURE(status) ((OTX_RESULT)(status) < 0)


// @type OTX_RESULT_CODE | Return the result portion of the return code
#define OTX_RESULT_CODE(ores) \
  ((((ores) & 0x000000ff) > OTX_RES_END) ? \
  ((OTX_RESULT)((ores) & 0x000000ff)) : \
  ((OTX_RESULT)((ores) & 0x800000ff)))

// @type OTX_RESULT_SEVERITY | Return the severity portion of the return code
#define OTX_RESULT_SEVERITY(ores)     (((ores) >> 31) & 0x1)

// @type OTX_RESULT_EX_SOURCE_ID | Return the source identifier
#define OTX_RESULT_SOURCE_ID(ores)    (((ores) >> 23) & 0xff) 

// @type OTX_RESULT_EX_LINE_NUM | Return the line number from the source identifier
#define OTX_RESULT_LINE_NUM(ores)     (((ores) >>  8) & 0x7fff)

// @type OTX_RESULT_ERRORCODE | Return the error code without the severity flag
#define OTX_RESULT_ERRORCODE(ores)    ((ores) & 0x000000ff)

// Only for use in Otx source files for creating result codes
#define OTX_MAKE_RESULT(errc,errstr)          ((OTX_RESULT) ( ((errc)&0x800000ff)|(((eSourceId)&0xff)<<23)|(((__LINE__)&0x7fff)<<8)))

// Only for use in Otx source files for creating result codes, with severity value
#define OTX_MAKE_RESULT_EX(sev,errc,errstr)   ((OTX_RESULT) ( ((unsigned long)(sev)<<31)|((errc)&0x000000ff)|(((eSourceId)&0xff)<<23)|(((__LINE__)&0x7fff)<<8)))

// Only for use in Otx header files when we do not have a static var named eSourceId
#define OTX_MAKE_RESULT_SRC(errc,esrcid,errstr)  ((OTX_RESULT) ( ((errc)&0x800000ff)|(((esrcid)&0xff)<<23)|(((__LINE__)&0x7fff)<<8)))

// Only for use in Otx header files when we do not have a static var named eSourceId AND the xxx_MAKE_RESULT_xxx is within a #define
#define OTX_MAKE_RESULT_SRC_LINE(errc,esrcid,eline,errstr)  ((OTX_RESULT) ( ((errc)&0x800000ff)|(((esrcid)&0xff)<<23)|(((eline)&0x7fff)<<8)))

// Only for use in Otx header files for defining the result codes
#define OTX_DEFINE_RESULT(sev,errc)           ((OTX_RESULT) (((unsigned long)(sev)<<31) | ((unsigned long)(errc))) )


/*--------------------------------------------------------------------------*\
  OTX general result codes used by all facilities

  Keep defines shorter than 31 chars since we must
  support MSC 5.1 technology
\*--------------------------------------------------------------------------*/

/******************************************************************************

  @enum
    Common Result Codes

  @devnote
    When result codes are added, remember to add the corresponding string
    to OdDevice.

 ******************************************************************************/
enum OtxCommonResultCodesE {
  OTX_RES_OK                 = 0x00,     // @emem Everything ok.                                                     
  OTX_RES_FALSE              = 0x01,     // @emem Everything ok, but result is logically false.                      
  OTX_RES_SIGNALLED          = 0x02,     // @emem An event was signalled.                                            
  OTX_RES_TIMEOUT            = 0x03,     // @emem A wait operation timed out.                                        
  OTX_RES_PENDING            = 0x04,     // @emem The data necessary to complete this operation is not yet available.
  OTX_RES_UNEXPECTED         = 0x05,     // @emem Unexpected situation.                                                      
  OTX_RES_NOTIMPL            = 0x06,     // @emem Not implemented.                                                           
  OTX_RES_OUTOFMEMORY        = 0x07,     // @emem Creation (new/malloc) failed, i.e. ran out of memory.                      
  OTX_RES_OUT_OF_RESOURCES   = 0x08,     // @emem Ran out of software resources.                                             
  OTX_RES_INVALIDARG         = 0x09,     // @emem One or more arguments are invalid.                                         
  OTX_RES_POINTER            = 0x0A,     // @emem Invalid pointer.                                                           
  OTX_RES_HANDLE             = 0x0B,     // @emem Invalid handle.                                                            
  OTX_RES_ABORT              = 0x0C,     // @emem Operation aborted.                                                         
  OTX_RES_FAIL               = 0x0D,     // @emem Unspecified error.                                                         
  OTX_RES_ACCESSDENIED       = 0x0E,     // @emem General access denied error.                                               
  OTX_RES_CALL_FAIL          = 0x0F,     // @emem Call into other process failed (e.g. app to driver).                       
  OTX_RES_NO_SUCH_OBJECT     = 0x10,     // @emem Reference to non-existent object or type, etc..                            
  OTX_RES_NOT_SUPPORTED      = 0x11,     // @emem Functionality not supported by the object.                                 
  OTX_RES_REG_NO             = 0x12,     // @emem Invalid Register Number.                                                   
  OTX_RES_BLOCKED            = 0x13,     // @emem Device Blocked.                                                            
  OTX_RES_NO_INTERRUPT       = 0x14,     // @emem No Interrupt.                                                              
  OTX_RES_WRONG_CONTEXT      = 0x15,     // @emem Call not allowed in the current context.                                   
  OTX_RES_NOT_INITIALIZED    = 0x16,     // @emem Device Object not properly initialized.                                    
  OTX_RES_ALREADY_EXISTS     = 0x17,     // @emem Attempted to create an already existing Device Object.                     
  OTX_RES_IN_USE             = 0x18,     // @emem The requested resource is already in use.                                  
  OTX_RES_BUSY               = 0x19,     // @emem The requested resource or function cannot service the request at this time.
  OTX_RES_NOT_WORKING        = 0x1A,     // @emem Device Object is not in working state.                                     
  OTX_RES_NOT_CONNECTED      = 0x1B,     // @emem Device Object is not connected.                                            
  OTX_RES_BUFFER_TO_SMALL    = 0x1C,     // @emem Buffer too small for return data.                                          
  OTX_RES_END                = 0x1D,
};                                
                                  

typedef enum OtxCommonResultCodesE OtxCommonResultCodesE;


/**********************************
  Success codes
  @devnote The following macros are kept for backwards compatibility, new code uses OtxCommonResultCodesE instead
**********************************/

#define OTX_S_OK                        OTX_DEFINE_RESULT(OTX_SEVERITY_SUCCESS, OTX_RES_OK        ) 
#define OTX_S_FALSE                     OTX_DEFINE_RESULT(OTX_SEVERITY_SUCCESS, OTX_RES_FALSE     ) 
#define OTX_S_SIGNALLED                 OTX_DEFINE_RESULT(OTX_SEVERITY_SUCCESS, OTX_RES_SIGNALLED ) 
#define OTX_S_TIMEOUT                   OTX_DEFINE_RESULT(OTX_SEVERITY_SUCCESS, OTX_RES_TIMEOUT   ) 
#define OTX_S_PENDING                   OTX_DEFINE_RESULT(OTX_SEVERITY_SUCCESS, OTX_RES_PENDING   ) 

/**********************************
  Failure codes
  @devnote The following macros are kept for backwards compatibility, new code uses OtxCommonResultCodesE instead
**********************************/

#define OTX_E_VOID                      0
#define OTX_E_UNEXPECTED                OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_UNEXPECTED      ) 
#define OTX_E_NOTIMPL                   OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_NOTIMPL         ) 
#define OTX_E_OUTOFMEMORY               OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_OUTOFMEMORY     ) 
#define OTX_E_OUT_OF_RESOURCES          OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_OUT_OF_RESOURCES) 
#define OTX_E_INVALIDARG                OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_INVALIDARG      ) 
#define OTX_E_POINTER                   OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_POINTER         ) 
#define OTX_E_HANDLE                    OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_HANDLE          ) 
#define OTX_E_ABORT                     OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_ABORT           ) 
#define OTX_E_FAIL                      OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_FAIL            ) 
#define OTX_E_ACCESSDENIED              OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_ACCESSDENIED    ) 
#define OTX_E_CALL_FAIL                 OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_CALL_FAIL       ) 
#define OTX_E_NO_SUCH_OBJECT            OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_NO_SUCH_OBJECT  ) 
#define OTX_E_NOT_SUPPORTED             OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_NOT_SUPPORTED   ) 
#define OTX_E_REG_NO                    OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_REG_NO          ) 
#define OTX_E_TIMEOUT                   OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_TIMEOUT         ) 
#define OTX_E_BLOCKED                   OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_BLOCKED         ) 
#define OTX_E_NO_INTERRUPT              OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_NO_INTERRUPT    ) 
#define OTX_E_WRONG_CONTEXT             OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_WRONG_CONTEXT   ) 
#define OTX_E_NOT_INITIALIZED           OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_NOT_INITIALIZED ) 
#define OTX_E_ALREADY_EXISTS            OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_ALREADY_EXISTS  ) 
#define OTX_E_IN_USE                    OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_IN_USE          ) 
#define OTX_E_BUSY                      OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_BUSY            ) 
#define OTX_E_NOT_WORKING               OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_NOT_WORKING     ) 
#define OTX_E_NOT_CONNECTED             OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_NOT_CONNECTED   ) 
#define OTX_E_BUFFER_TO_SMALL           OTX_DEFINE_RESULT(OTX_SEVERITY_ERROR  , OTX_RES_BUFFER_TO_SMALL ) 

/*-------------------------------*\
  Result Code Source Identifiers
  see OTX_RESULT_SOURCE_ID()
\*-------------------------------*/

enum OtxSourceIdE {
  OTX_SRC_SOURCE_ID_NONE                    = 0,
  OTX_SRC_DRV_ODASM_CPP                     = 1,
  OTX_SRC_DRV_ODVIDAR55X4ASM_CPP            = 2,
  OTX_SRC_DRV_ODVIDAR5X4CST_CPP             = 3,
  OTX_SRC_DRV_ODVIDAR5X4EX_CPP              = 4,
  OTX_SRC_DRV_ODVIDAR5X4PRO_CPP             = 5,
  OTX_SRC_DRV_ODVIDAR5XNASM_CPP             = 6,
  OTX_SRC_DRV_ODDEBUG_CPP                   = 7,
  OTX_SRC_DRV_ODDEVICE_CPP                  = 8,
  OTX_SRC_DRV_ODEVENTQUEUE_CPP              = 9,
  OTX_SRC_DRV_ODHWDEVICE_CPP                = 10,
  OTX_SRC_DRV_ODLOGICALDEVICE_CPP           = 11,
  OTX_SRC_DRV_ODPIPE_CPP                    = 12,
  OTX_SRC_DRV_ODPNPDEVICE_CPP               = 13,
  OTX_SRC_DRV_ODUTILS_CPP                   = 14,
  OTX_SRC_DRV_ODAIC_CPP                     = 15,
  OTX_SRC_DRV_ODALIS_CPP                    = 16,
  OTX_SRC_DRV_ODAMB_CPP                     = 17,
  OTX_SRC_DRV_ODBURST_CPP                   = 18,
  OTX_SRC_DRV_ODCODEC_CPP                   = 19,
  OTX_SRC_DRV_ODCTBUS_CPP                   = 20,
  OTX_SRC_DRV_ODDSP_CPP                     = 21,
  OTX_SRC_DRV_ODDSPC5400X_CPP               = 22,
  OTX_SRC_DRV_ODDSPC5410A_CPP               = 23,
  OTX_SRC_DRV_ODDSPC5416_CPP                = 24,
  OTX_SRC_DRV_ODDSPC548C549_CPP             = 25,
  OTX_SRC_DRV_ODDSPC54CST_CPP               = 26,
  OTX_SRC_DRV_ODDSPC54X_CPP                 = 27,
  OTX_SRC_DRV_ODDSPC55X_CPP                 = 28,
  OTX_SRC_DRV_ODEEPROM_CPP                  = 29,
  OTX_SRC_DRV_ODEEPROMNM93CS46_CPP          = 30,
  OTX_SRC_DRV_ODEEPROMNM93CS56_CPP          = 31,
  OTX_SRC_DRV_ODFALC_CPP                    = 32,
  OTX_SRC_DRV_ODFALC56_CPP                  = 33,
  OTX_SRC_DRV_ODFPGASPARTAN_CPP             = 34,
  OTX_SRC_DRV_ODFSFIFO_CPP                  = 35,
  OTX_SRC_DRV_ODISAC_CPP                    = 36,
  OTX_SRC_DRV_ODPLX_CPP                     = 37,
  OTX_SRC_DRV_ODPLX9056_CPP                 = 38,
  OTX_SRC_DRV_ODQUADFALC_CPP                = 39,
  OTX_SRC_DRV_ODQUADFALCMEMBER_CPP          = 40,
  OTX_SRC_DRV_ODRINGBUF_CPP                 = 41,
  OTX_SRC_DRV_ODTBC_CPP                     = 42,
  OTX_SRC_DRV_DRIVERENTRY_CPP               = 43,
  OTX_SRC_DRV_ODDRIVER_CPP                  = 44,
  OTX_SRC_DRV_ODDRIVERDEVICE_CPP            = 45,
  OTX_SRC_DRV_ODE1ABCDBITACCESS_CPP         = 46,
  OTX_SRC_DRV_ODE1SBITACCESS_CPP            = 47,
  OTX_SRC_DRV_ODFALCE1ABCDBITACCESS_CPP     = 48,
  OTX_SRC_DRV_ODFALCE1SBITACCESS_CPP        = 49,
  OTX_SRC_DRV_ODFALCHDLCRECEIVER_CPP        = 50,
  OTX_SRC_DRV_ODFALCHDLCSENDER_CPP          = 51,
  OTX_SRC_DRV_ODFALCT1DLBITACCESS_CPP       = 52,
  OTX_SRC_DRV_ODFALCT1ROBBITACCESS_CPP      = 53,
  OTX_SRC_DRV_ODHDLCDEVICE_CPP              = 54,
  OTX_SRC_DRV_ODHDLCRECEIVER_CPP            = 55,
  OTX_SRC_DRV_ODHDLCSENDER_CPP              = 56,
  OTX_SRC_DRV_ODRAWDATA_CPP                 = 57,
  OTX_SRC_DRV_ODRAWDATARECEIVER_CPP         = 58,
  OTX_SRC_DRV_ODRAWDATASENDER_CPP           = 59,
  OTX_SRC_DRV_ODSPM1CONSTVALGENERATOR_CPP   = 60,
  OTX_SRC_DRV_ODSPM1DATACONVERTER_CPP       = 61,
  OTX_SRC_DRV_ODSPM1DTMFDETECTOR_CPP        = 62,
  OTX_SRC_DRV_ODSPM1DTMFDIALER_CPP          = 63,
  OTX_SRC_DRV_ODSPM1DUALDETECTOR_CPP        = 64,
  OTX_SRC_DRV_ODSPM1EFFECTSGENERATOR_CPP    = 65,
  OTX_SRC_DRV_ODSPM1FSKDETECTOR_CPP         = 66,
  OTX_SRC_DRV_ODSPM1HDLCRECEIVER_CPP        = 67,
  OTX_SRC_DRV_ODSPM1HDLCSENDER_CPP          = 68,
  OTX_SRC_DRV_ODSPM1MFDETECTOR_CPP          = 69,
  OTX_SRC_DRV_ODSPM1MFDIALER_CPP            = 70,
  OTX_SRC_DRV_ODSPM1RAWDATARECEIVER_CPP     = 71,
  OTX_SRC_DRV_ODSPM1RAWDATASENDER_CPP       = 72,
  OTX_SRC_DRV_ODSPM1SILENCEDETECTOR_CPP     = 73,
  OTX_SRC_DRV_ODSPM1SINEWAVEGENERATOR_CPP   = 74,
  OTX_SRC_DRV_ODSPM1SINGLEDETECTOR_CPP      = 75,
  OTX_SRC_DRV_ODSPM1VALSAMPLER_CPP          = 76,
  OTX_SRC_DRV_ODSPMLOGICALDEVICE_CPP        = 77,
  OTX_SRC_DRV_ODT1DLBITACCESS_CPP           = 78,
  OTX_SRC_DRV_ODT1E1BITACCESS_CPP           = 79,
  OTX_SRC_DRV_ODT1ROBBITACCESS_CPP          = 80,
  OTX_SRC_DRV_ODUSERAPPLICATION_CPP         = 81,
  OTX_SRC_DRV_ODNIC_CPP                     = 82,
  OTX_SRC_DRV_ODARNI32PCI_CPP               = 83,
  OTX_SRC_DRV_ODBALDER8SPCI_CPP             = 84,
  OTX_SRC_DRV_ODBALDER8UPCI_CPP             = 85,
  OTX_SRC_DRV_ODHERMODPCI_CPP               = 86,
  OTX_SRC_DRV_ODNIC1BUS_CPP                 = 87,
  OTX_SRC_DRV_ODTHOR2PCI_CPP                = 88,
  OTX_SRC_DRV_ODTHOR8PCI_CPP                = 89,
  OTX_SRC_DRV_ODVIDAR5XNPCI_CPP             = 90,
  OTX_SRC_DRV_ODNICPCMCIA_CPP               = 91,
  OTX_SRC_DRV_ODTHOR2PCMCIA_CPP             = 92,
  OTX_SRC_DRV_ODTHOR2PCMCIAPLUS_CPP         = 93,
  OTX_SRC_DRV_ODTHOR2PCMCIAPLUSC549_CPP     = 94,
  OTX_SRC_DRV_ODTHOR2PCMCIAPLUSCST_CPP      = 95,
  OTX_SRC_DRV_ODTHOR2PCMCIAPLUSEX_CPP       = 96,
  OTX_SRC_DRV_ODTHOR2PCMCIAPLUSPRO_CPP      = 97,
  OTX_SRC_DRV_ODTHOR2PCMCIASTD_CPP          = 98,
  OTX_SRC_DRV_ODNICPLUS_CPP                 = 99,
  OTX_SRC_DRV_ODSLEIPNIR_CPP                = 100,
  OTX_SRC_DRV_ODTHOR8PCIPLUS_CPP            = 101,
  OTX_SRC_LIB_OTXBRD_C                      = 102,
  OTX_SRC_LIB_OTXBRI_C                      = 103,
  OTX_SRC_LIB_OTXBURST_C                    = 104,
  OTX_SRC_LIB_OTXDATA_C                     = 105,
  OTX_SRC_LIB_OTXDRV_C                      = 106,
  OTX_SRC_LIB_OTXDSP_C                      = 107,
  OTX_SRC_LIB_OTXHDLC_C                     = 108,
  OTX_SRC_LIB_OTXJTAG_C                     = 109,
  OTX_SRC_LIB_OTXPOTS_C                     = 110,
  OTX_SRC_LIB_OTXRAW_C                      = 111,
  OTX_SRC_LIB_OTXT1E1_C                     = 112,
  OTX_SRC_LIB_OTXTONE_C                     = 113,
  OTX_SRC_LIB_OTXTST_C                      = 114,
  OTX_SRC_DRV_ODASM_H                       = 115,
  OTX_SRC_DRV_ODDEVICE_H                    = 116,
  OTX_SRC_DRV_ODFIFO_H                      = 117,
  OTX_SRC_DRV_ODHWDEVICE_H                  = 118,
  OTX_SRC_DRV_ODLOGICALDEVICE_H             = 119,
  OTX_SRC_DRV_ODPNPDEVICE_H                 = 120,
  OTX_SRC_DRV_ODDSP_H                       = 121,
  OTX_SRC_DRV_ODFALC_H                      = 122,
  OTX_SRC_DRV_ODPLX_H                       = 123,
  OTX_SRC_DRV_ODE1ABCDBITACCESS_H           = 124,
  OTX_SRC_DRV_ODE1SBITACCESS_H              = 125,
  OTX_SRC_DRV_ODHDLCRECEIVER_H              = 126,
  OTX_SRC_DRV_ODHDLCSENDER_H                = 127,
  OTX_SRC_DRV_ODT1DLBITACCESS_H             = 128,
  OTX_SRC_DRV_ODT1ROBBITACCESS_H            = 129,
  OTX_SRC_DRV_ODNIC_H                       = 130,
  OTX_SRC_DRV_ODNIC1BUS_H                   = 131,
  OTX_SRC_DRV_ODTHOR2PCMCIA_H               = 132,
  OTX_SRC_DRV_ODTHOR2PCMCIAPLUS_H           = 133,
  OTX_SRC_LIB_OTXLIB_H                      = 134,
  OTX_SRC_DRV_ODFALC56_H                    = 135,
  OTX_SRC_DRV_ODGIMLE16PCIPLUS_CPP          = 136,
  OTX_SRC_LIB_OSABOARD_C                    = 137,
  OTX_SRC_OSA_OSANDISOID_CPP                = 138,

  // DEV NOTE: Please update OtxResult.c when adding new sources.

  OTX_SRC_SOURCE_ID_COUNT                   = 139,
  OTX_SRC_SOURCE_ID_MAX                     = 255
};                                
typedef enum OtxSourceIdE OtxSourceIdE;


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998 - 2004


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif   // OTX_ERR_H
